@@ -29,6 +29,7 @@ class TarFile(tarfile.TarFile):
         if fileobj is not None:
             fileobj = FileWrapper(fileobj, self.get_progress(tarinfo.size, desc=tarinfo.name))
         result = super(TarFile, self).addfile(tarinfo, fileobj)
+        self._progress_callback.close()
         return result
 
     def extractall(self, path=".", members=None, **kwargs):
@@ -42,6 +43,7 @@ class TarFile(tarfile.TarFile):
 
         result = super(TarFile, self).extractall(path, members)
         self.fileobj = original
+        self._progress_callback.close()
         return result
 
     def extract(self, member, path="", **kwargs):
@@ -51,9 +53,8 @@ class TarFile(tarfile.TarFile):
     def extractfile(self, member):
         fileobj = super(TarFile, self).extractfile(member)
         if fileobj is not None:
-            fileobj = FileWrapper(fileobj, self.get_progress(member.size, desc=member.name))
+            fileobj = FileWrapper(fileobj, self.get_progress(member.size, desc=member.name))        
 
-        return fileobj
 
 
 class FileWrapper(object):
